==> plotly.js-1.54.1.jar: META-INF/resources/webjars/plotly.js/1.54.1/lib/locales/cs.js <==
/**
* Copyright 2012-2020, Plotly, Inc.
* All rights reserved.
*
* This source code is licensed under the MIT license found in the
* LICENSE file in the root directory of this source tree.
*/

'use strict';

module.exports = {
    moduleType: 'locale',
    name: 'cs',
    dictionary: {
        'Autoscale': 'Auto rozsah',                                                             // components/modebar/buttons.js:139
        'Box Select': 'Obdélníkový výběr',                                                                    // components/modebar/buttons.js:103
        'Click to enter Colorscale title': 'Klikněte pro zadání názvu barevné škály',                     // plots/plots.js:437
        'Click to enter Component A title': 'Klikněte pro zadání názvu komponenty A',            // plots/ternary/ternary.js:386
        'Click to enter Component B title': 'Klikněte pro zadání názvu komponenty B',            // plots/ternary/ternary.js:400
        'Click to enter Component C title': 'Klikněte pro zadání názvu komponenty C',            // plots/ternary/ternary.js:411
        'Click to enter Plot title': 'Klikněte pro zadání názvu grafu',                        // plot_api/plot_api.js:579
        'Click to enter X axis title': 'Klikněte pro zadání názvu osy X',                      // plots/plots.js:435
        'Click to enter Y axis title': 'Klikněte pro zadání názvu osy Y',                      // plots/plots.js:436
        'Click to enter radial axis title': 'Klikněte pro zadání názvu radiální osy',          // plots/polar/polar.js:376
        'Compare data on hover': 'Porovnat hodnoty při najetí myší',                            // components/modebar/buttons.js:167
        'Double-click on legend to isolate one trace': 'Dvojklikem na legendu izolujete jedinou datovou sadu',  // components/legend/handle_click.js:90
        'Double-click to zoom back out': 'Dvojklikem vrátíte zvětšení',                                  // plots/cartesian/dragbox.js:299
        'Download plot as a png': 'Uložit jsko PNG',                                                       // components/modebar/buttons.js:52
        'Download plot': 'Uložit',                                                                         // components/modebar/buttons.js:53
        'Edit in Chart Studio': 'Editovat v Chart Studio',                                               // components/modebar/buttons.js:76
        'IE only supports svg.  Changing format to svg.': 'IE podporuje pouze SVG formát. Změněno na SVG.', // components/modebar/buttons.js:60
        'Lasso Select': 'Vyběr lasem',                                                                     // components/modebar/buttons.js:112
        'Orbital rotation': 'Rotace (orbitální)',                                                              // components/modebar/buttons.js:279
        'Pan': 'Posunovat',                                                                               // components/modebar/buttons.js:94
        'Produced with Plotly': 'Vytvořeno pomocí Plotly',                                                      // components/modebar/modebar.js:256
        'Reset': 'Obnovit nastavení',                                                                            // components/modebar/buttons.js:432
        'Reset axes': 'Obnovit nastavení os',                                                                // components/modebar/buttons.js:148
        'Reset camera to default': 'Obnovit nastavení kamery na výchozí stav',                                      // components/modebar/buttons.js:314
        'Reset camera to last save': 'Obnovit nastavení kamery na poslední uložený stav',                          // components/modebar/buttons.js:322
        'Reset view': 'Obnovit nastavení pohledu',                                                               // components/modebar/buttons.js:583
        'Reset views': 'Obnovit nastavení pohledů',                                                            // components/modebar/buttons.js:529
        'Show closest data on hover': 'Zobrazit najbližší hodnotu při najetí myší',                                // components/modebar/buttons.js:157
        'Snapshot succeeded': 'Snímek vytvořen',                                                       // components/modebar/buttons.js:66
        'Sorry, there was a problem downloading your snapshot!': 'Omlouváme se, ale došlo k chybě stahování snímku!', // components/modebar/buttons.js:69
        'Taking snapshot - this may take a few seconds': 'Vytváří se snímek - může zabrat pár vteřin', // components/modebar/buttons.js:57
        'Zoom': 'Zvětšení',                                                                                     // components/modebar/buttons.js:85
        'Zoom in': 'Zvětšit',                                                                          // components/modebar/buttons.js:121
        'Zoom out': 'Zmenšit',                                                                         // components/modebar/buttons.js:130
        'close:': 'zavřít:',                                                                               // traces/ohlc/transform.js:139
        'trace': 'datová sada',                                                                               // plots/plots.js:439
        'lat:': 'Lat.:',                                                                                    // traces/scattergeo/calc.js:48
        'lon:': 'Lon.:',                                                                                    // traces/scattergeo/calc.js:49
        'q1:': 'q1:',                                                                                        // traces/box/calc.js:130
        'q3:': 'q3:',                                                                                        // traces/box/calc.js:131
        'source:': 'zdroj:',                                                                               // traces/sankey/plot.js:140
        'target:': 'cíl:',                                                                                 // traces/sankey/plot.js:141
        'lower fence:': 'dolní limit:',                                                                 // traces/box/calc.js:134
        'upper fence:': 'horní limit:',                                                                  // traces/box/calc.js:135
        'max:': 'max.:',                                                                                    // traces/box/calc.js:132
        'mean ± σ:': 'průměr ± σ:',                                                                     // traces/box/calc.js:133
        'mean:': 'průměr:',                                                                             // traces/box/calc.js:133
        'median:': 'medián:',                                                                               // traces/box/calc.js:128
        'min:': 'min.:',                                                                                    // traces/box/calc.js:129
        'new text': 'nový text',                                               // plots/plots.js:318
        'Turntable rotation': 'Rotace (otočný stůl)',                                                          // components/modebar/buttons.js:288
        'Toggle Spike Lines': 'Přepnout zobrazení vodících čar',                                                // components/modebar/buttons.js:548
        'open:': 'otevřít:',                                                                              // traces/ohlc/transform.js:136
        'high:': 'horní:',                                                                             // traces/ohlc/transform.js:137
        'low:': 'dolní:',                                                                              // traces/ohlc/transform.js:138
        'Toggle show closest data on hover': 'Přepnout zobrazování nejbližši hodnoty při najetí myší',                   // components/modebar/buttons.js:353
        'incoming flow count:': 'počet dat na vstupu:',                                          // traces/sankey/plot.js:142
        'outgoing flow count:': 'počet dat na výstupu:',                                          // traces/sankey/plot.js:143
        'kde:': 'kde:'                                                                       // traces/violin/calc.js:73
    },
    format: {
        days: ['neděle', 'pondělí', 'úterý', 'středa', 'čtvrtek', 'pátek', 'sobota'],
        shortDays: ['ne', 'po', 'út', 'st', 'čt', 'pá', 'so'],
        months: [
            'leden', 'únor', 'březen', 'duben', 'květen', 'červen',
            'červenec', 'srpen', 'září', 'říjen', 'listopad', 'prosinec'
        ],
        shortMonths: [
            'led', 'úno', 'bře', 'dub', 'kvě', 'čer',
            'čvc', 'srp', 'zář', 'říj', 'lis', 'pro'
        ],
        date: '%d.%m.%Y'
    }
};

==> plotly.js-2.33.0.jar: META-INF/resources/webjars/plotly.js/2.33.0/lib/locales/cs.js <==
'use strict';

module.exports = {
    moduleType: 'locale',
    name: 'cs',
    dictionary: {
        'Autoscale': 'Auto rozsah',                                                             // components/modebar/buttons.js:139
        'Box Select': 'Obdélníkový výběr',                                                                    // components/modebar/buttons.js:103
        'Click to enter Colorscale title': 'Klikněte pro zadání názvu barevné škály',                     // plots/plots.js:437
        'Click to enter Component A title': 'Klikněte pro zadání názvu komponenty A',            // plots/ternary/ternary.js:386
        'Click to enter Component B title': 'Klikněte pro zadání názvu komponenty B',            // plots/ternary/ternary.js:400
        'Click to enter Component C title': 'Klikněte pro zadání názvu komponenty C',            // plots/ternary/ternary.js:411
        'Click to enter Plot title': 'Klikněte pro zadání názvu grafu',                        // plot_api/plot_api.js:579
        'Click to enter X axis title': 'Klikněte pro zadání názvu osy X',                      // plots/plots.js:435
        'Click to enter Y axis title': 'Klikněte pro zadání názvu osy Y',                      // plots/plots.js:436
        'Click to enter radial axis title': 'Klikněte pro zadání názvu radiální osy',          // plots/polar/polar.js:376
        'Compare data on hover': 'Porovnat hodnoty při najetí myší',                            // components/modebar/buttons.js:167
        'Double-click on legend to isolate one trace': 'Dvojklikem na legendu izolujete jedinou datovou sadu',  // components/legend/handle_click.js:90
        'Double-click to zoom back out': 'Dvojklikem vrátíte zvětšení',                                  // plots/cartesian/dragbox.js:299
        'Download plot as a png': 'Uložit jako PNG',                                                       // components/modebar/buttons.js:52
        'Download plot': 'Uložit',                                                                         // components/modebar/buttons.js:53
        'Edit in Chart Studio': 'Editovat v Chart Studio',                                               // components/modebar/buttons.js:76
        'IE only supports svg.  Changing format to svg.': 'IE podporuje pouze SVG formát. Změněno na SVG.', // components/modebar/buttons.js:60
        'Lasso Select': 'Vyběr lasem',                                                                     // components/modebar/buttons.js:112
        'Orbital rotation': 'Rotace (orbitální)',                                                              // components/modebar/buttons.js:279
        'Pan': 'Posunovat',                                                                               // components/modebar/buttons.js:94
        'Produced with Plotly.js': 'Vytvořeno pomocí Plotly.js',                                                // components/modebar/modebar.js:256
        'Reset': 'Obnovit nastavení',                                                                            // components/modebar/buttons.js:432
        'Reset axes': 'Obnovit nastavení os',                                                                // components/modebar/buttons.js:148
        'Reset camera to default': 'Obnovit nastavení kamery na výchozí stav',                                      // components/modebar/buttons.js:314
        'Reset camera to last save': 'Obnovit nastavení kamery na poslední uložený stav',                          // components/modebar/buttons.js:322
        'Reset view': 'Obnovit nastavení pohledu',                                                               // components/modebar/buttons.js:583
        'Reset views': 'Obnovit nastavení pohledů',                                                            // components/modebar/buttons.js:529
        'Show closest data on hover': 'Zobrazit najbližší hodnotu při najetí myší',                                // components/modebar/buttons.js:157
        'Snapshot succeeded': 'Snímek vytvořen',                                                       // components/modebar/buttons.js:66
        'Sorry, there was a problem downloading your snapshot!': 'Omlouváme se, ale došlo k chybě stahování snímku!', // components/modebar/buttons.js:69
        'Taking snapshot - this may take a few seconds': 'Vytváří se snímek - může zabrat pár vteřin', // components/modebar/buttons.js:57
        'Zoom': 'Zvětšení',                                                                                     // components/modebar/buttons.js:85
        'Zoom in': 'Zvětšit',                                                                          // components/modebar/buttons.js:121
        'Zoom out': 'Zmenšit',                                                                         // components/modebar/buttons.js:130
        'close:': 'zavřít:',                                                                               // traces/ohlc/transform.js:139
        'trace': 'datová sada',                                                                               // plots/plots.js:439
        'lat:': 'Lat.:',                                                                                    // traces/scattergeo/calc.js:48
        'lon:': 'Lon.:',                                                                                    // traces/scattergeo/calc.js:49
        'q1:': 'q1:',                                                                                        // traces/box/calc.js:130
        'q3:': 'q3:',                                                                                        // traces/box/calc.js:131
        'source:': 'zdroj:',                                                                               // traces/sankey/plot.js:140
        'target:': 'cíl:',                                                                                 // traces/sankey/plot.js:141
        'lower fence:': 'dolní limit:',                                                                 // traces/box/calc.js:134
        'upper fence:': 'horní limit:',                                                                  // traces/box/calc.js:135
        'max:': 'max.:',                                                                                    // traces/box/calc.js:132
        'mean ± σ:': 'průměr ± σ:',                                                                     // traces/box/calc.js:133
        'mean:': 'průměr:',                                                                             // traces/box/calc.js:133
        'median:': 'medián:',                                                                               // traces/box/calc.js:128
        'min:': 'min.:',                                                                                    // traces/box/calc.js:129
        'new text': 'nový text',                                               // plots/plots.js:318
        'Turntable rotation': 'Rotace (otočný stůl)',                                                          // components/modebar/buttons.js:288
        'Toggle Spike Lines': 'Přepnout zobrazení vodících čar',                                                // components/modebar/buttons.js:548
        'open:': 'otevřít:',                                                                              // traces/ohlc/transform.js:136
        'high:': 'horní:',                                                                             // traces/ohlc/transform.js:137
        'low:': 'dolní:',                                                                              // traces/ohlc/transform.js:138
        'Toggle show closest data on hover': 'Přepnout zobrazování nejbližši hodnoty při najetí myší',                   // components/modebar/buttons.js:353
        'incoming flow count:': 'počet dat na vstupu:',                                          // traces/sankey/plot.js:142
        'outgoing flow count:': 'počet dat na výstupu:',                                          // traces/sankey/plot.js:143
        'kde:': 'kde:'                                                                       // traces/violin/calc.js:73
    },
    format: {
        days: ['neděle', 'pondělí', 'úterý', 'středa', 'čtvrtek', 'pátek', 'sobota'],
        shortDays: ['ne', 'po', 'út', 'st', 'čt', 'pá', 'so'],
        months: [
            'leden', 'únor', 'březen', 'duben', 'květen', 'červen',
            'červenec', 'srpen', 'září', 'říjen', 'listopad', 'prosinec'
        ],
        shortMonths: [
            'led', 'úno', 'bře', 'dub', 'kvě', 'čer',
            'čvc', 'srp', 'zář', 'říj', 'lis', 'pro'
        ],
        date: '%d.%m.%Y',
        decimal: ',',
        thousands: ' '
    }
};
